OP_INPUT_NORM = 0
OP_CONV1D_TERNARY = 1
OP_DENSE_TERNARY = 2
OP_CONV2D_TERNARY = 3
OP_RELU = 10
OP_LEAKY_RELU = 11
OP_SOFTMAX = 12
OP_SIGMOID = 13
OP_TANH = 14
OP_MAXPOOL_1D = 20
OP_AVGPOOL_1D = 21
OP_FLATTEN = 22
OP_DROPOUT = 23
OP_BATCH_NORM = 30
OP_LSTM = 40
OP_GRU = 41
OP_CUSTOM = 255
